@@ -22,33 +22,29 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef KCM_H
 #define KCM_H
 
+#include <KConfigPropertyMap>
 #include <KPackage/Package>
 #include <KQuickAddons/ManagedConfigModule>
 
 #include "kscreensaversettings.h"
+#include "wallpaper_integration.h"
 
 class ScreenLockerKcmForm;
 class AppearanceSettings;
 namespace ScreenLocker
 {
-class WallpaperIntegration;
 class LnFIntegration;
 }
 
-namespace KDeclarative
-{
-class ConfigPropertyMap;
-}
-
 class ScreenLockerKcm : public KQuickAddons::ManagedConfigModule
 {
     Q_OBJECT
 public:
-    explicit ScreenLockerKcm(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+    explicit ScreenLockerKcm(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
 
     Q_PROPERTY(KScreenSaverSettings *settings READ settings CONSTANT)
-    Q_PROPERTY(KDeclarative::ConfigPropertyMap *wallpaperConfiguration READ wallpaperConfiguration NOTIFY currentWallpaperChanged)
-    Q_PROPERTY(KDeclarative::ConfigPropertyMap *lnfConfiguration READ lnfConfiguration CONSTANT)
+    Q_PROPERTY(KConfigPropertyMap *wallpaperConfiguration READ wallpaperConfiguration NOTIFY currentWallpaperChanged)
+    Q_PROPERTY(KConfigPropertyMap *lnfConfiguration READ lnfConfiguration CONSTANT)
     Q_PROPERTY(QUrl lnfConfigFile READ lnfConfigFile CONSTANT)
     Q_PROPERTY(QUrl wallpaperConfigFile READ wallpaperConfigFile NOTIFY currentWallpaperChanged)
     Q_PROPERTY(ScreenLocker::WallpaperIntegration *wallpaperIntegration READ wallpaperIntegration NOTIFY currentWallpaperChanged)
@@ -81,8 +77,8 @@ private:
     bool isSaveNeeded() const override;
     bool isDefaults() const override;
 
-    KDeclarative::ConfigPropertyMap *wallpaperConfiguration() const;
-    KDeclarative::ConfigPropertyMap *lnfConfiguration() const;
+    KConfigPropertyMap *wallpaperConfiguration() const;
+    KConfigPropertyMap *lnfConfiguration() const;
 
     AppearanceSettings *m_appearanceSettings;
     QString m_currentWallpaper;
