@@ -38,6 +38,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KAuthorized>
 #include <KGlobalAccel>
 #include <KIdleTime>
+#include <KLibexec>
 #include <KLocalizedString>
 #include <KNotification>
 
@@ -46,7 +47,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QKeyEvent>
 #include <QProcess>
 #include <QTimer>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
 // X11
 #include <X11/Xlib.h>
 #include <xcb/xcb.h>
@@ -612,8 +617,13 @@ void KSldApp::startLockProcess(EstablishLock establishLock)
     args << QStringLiteral("--ksldfd");
     args << QString::number(fd);
 
+    auto greeterPath = KLibexec::path(QStringLiteral(KSCREENLOCKER_GREET_BIN_REL));
+    if (!QFile::exists(greeterPath)) {
+        greeterPath = KSCREENLOCKER_GREET_BIN_ABS;
+    }
+
     m_lockProcess->setProcessEnvironment(env);
-    m_lockProcess->start(QStringLiteral(KSCREENLOCKER_GREET_BIN), args);
+    m_lockProcess->start(greeterPath, args);
     close(fd);
 }
 
